@@ -3,7 +3,7 @@ import torch.nn as nn
 import torch.nn.functional as F
 import torch.linalg as LA
 from torch.nn.attention.flex_attention import flex_attention, create_block_mask
-# if torch.cuda.is_available(): flex_attention = torch.compile(flex_attention, backend="aot_eager")
+if torch.cuda.is_available(): flex_attention = torch.compile(flex_attention)
 import math
 import warnings
 import opt_einsum
@@ -490,51 +490,6 @@ class SlidingWindowAttention(nn.Module):
 
         mask = torch.where(allowed, 0.0, float('-inf'))
         return mask
-
-    def shift(self, x, shifts, dims, fill_value=None, shift_min_max=None):
-        # dims: (dim_src, dim_shift)
-        # shifts: (S,) tensor of ints
-        dim_src, dim_shift = dims
-
-        # 1) move dims → [S, L, *rest]
-        x2 = x.movedim((dim_src, dim_shift), (0, 1))
-        S, L, *rest = x2.shape
-        # flat_D = x2.numel() // (S * L)
-
-        if shift_min_max is not None:
-            s_min, s_max = shift_min_max
-        else:
-            if torch.is_tensor(shifts):
-                s_min, s_max = shifts.min(), shifts.max()
-            else:
-                s_min, s_max = min(shifts), max(shifts)
-        s_min, s_max = torch.as_tensor(s_min, device=x.device), torch.as_tensor(s_max, device=x.device)
-        H_neg = torch.clamp(-s_min, min=0)
-        H_pos = torch.clamp( s_max, min=0)
-        ext_L = L + H_neg + H_pos
-
-        # 3) allocate & fill
-        if fill_value is None:
-            padded = x2.new_empty((S, ext_L, *rest))
-        else:
-            padded = x2.new_full((S, ext_L, *rest), fill_value)
-
-        # 4) build destination indices
-        #   pos: (1, L)
-        pos = torch.arange(L, device=x.device).view(1, L)
-        #   shifts: (S,1)
-        sh = shifts.view(S, 1)
-        #   dest: (S, L)
-        dest = pos + sh + H_neg
-
-        # 5) scatter all at once
-        x_flat = x2.reshape(S, L, -1)
-        dest_exp = dest.view(S, L, 1).expand(x_flat.shape)
-        padded.reshape(S, ext_L, -1).scatter_(1, dest_exp, x_flat)
-
-        # 6) slice & move dims back
-        out2 = padded[:, H_neg : H_neg + L]
-        return out2.movedim((0,1), dims)
     
     @lru_cache(maxsize=2)
     def causal_windowed_block_mask(self, src_len, tgt_len=None, device=None):
@@ -613,7 +568,7 @@ class SlidingWindowAttention(nn.Module):
             # Convert attention weights to probabilities
             attn_output_weights = F.softmax(attn_output_weights, dim=-1)
             attn_output_weights = F.dropout(attn_output_weights, p=self.dropout, training=self.training)
-                        
+            
             # Apply attention weights to values
             attn_output = torch.bmm(attn_output_weights, v)[:, :src_len]  # (bsz * n_heads, src_len, d_head)
             
@@ -639,43 +594,9 @@ class SlidingWindowAttention(nn.Module):
             k = rearrange(k, '(b h) s d -> b h s d', h=self.n_heads).contiguous()
             v = rearrange(v, '(b h) s d -> b h s d', h=self.n_heads).contiguous()
             
-            with torch._dynamo.disable():
-                attn_output = flex_attention(q, k, v, block_mask=block_mask)[:, :, :src_len]
+            attn_output = flex_attention(q, k, v, block_mask=block_mask)[:, :, :src_len]
             
             attn_output = rearrange(attn_output, 'b h s d -> s b (h d)', h=self.n_heads).contiguous().to(self.device)
-            
-            # if causal:
-            #     pad_amount = min(src_len-1, (self.window_len-1) * self.dilation)
-            #     pad = (0, pad_amount)
-            # else:
-            #     pad_amount = self.dilation * min((src_len - 1) // self.dilation, self.window_len // 2)
-            #     pad = (pad_amount, pad_amount)
-
-            # q = dilated_sliding_window(q, size=src_len, dim=1, stride=self.dilation, dilation=1, pad=pad)
-
-            # attn_output_weights = torch.einsum('zbsd, zsd -> zbs', q, k)  # (bsz * n_heads, n_bands, src_len)
-            
-            # shifts = torch.arange(-pad[0], pad[1]+1, self.dilation, device=self.device)
-            # attn_output_weights = self.shift(attn_output_weights, shifts, shift_min_max=(shifts[0], shifts[-1]), dims=(1, 2), fill_value=float('-inf'))
-            
-            # if self.attn_sink:
-            #     sink_weight = torch.zeros((bsz * self.n_heads, 1, src_len), dtype=x.dtype, device=self.device)  # (bsz * n_heads, 1, src_len)
-            #     attn_output_weights = torch.cat([attn_output_weights, sink_weight], dim=1)  # (bsz * n_heads, n_bands+1, src_len)
-            
-            # # Convert attention weights to probabilities
-            # attn_output_weights = F.softmax(attn_output_weights, dim=1)
-            # attn_output_weights = F.dropout(attn_output_weights, p=self.dropout, training=self.training)
-            
-            # if self.attn_sink: attn_output_weights = attn_output_weights[:, :-1]
-            
-            # attn_output_weights = self.shift(attn_output_weights, -shifts, shift_min_max=(-shifts[-1], -shifts[0]), dims=(1, 2), fill_value=0.0)
-            
-            # # Apply attention weights to values
-            # attn_output = attn_output_weights.unsqueeze(-1) * v.unsqueeze(1)
-            
-            # attn_output = self.shift(attn_output, shifts, shift_min_max=(shifts[0], shifts[-1]), dims=(1, 2), fill_value=0.0)
-            
-            # attn_output = attn_output.sum(dim=1)
         
         # Apply final projection
         attn_output = self.out_proj(attn_output)
