@@ -346,10 +346,10 @@ def train(epochs, train_steps, benchmark_name, model, train_loader, optimizer, l
         # Use multiple GPUs if available
         if torch.cuda.device_count() > 1: model = nn.DataParallel(model)
         
-        # Allocate dynamic memory if applicable for dataset
         if hasattr(train_loader.dataset, "seq_len_range"):
+            # Allocate dynamic memory if applicable for dataset
             min_len, max_len = train_loader.dataset.seq_len_range()
-            model = allocate_dynamic_memory(model, train_loader.batch_size, min_len, max_len, device)
+            model = allocate_dynamic_memory(model, train_loader.batch_size, min_len, max_len, compile_backend, device)
         else:
             # Compile the model for faster training
             model = compile_model(model, train_loader.dataset[0][0].shape, compile_backend, device)
@@ -478,8 +478,8 @@ def train_from_config_file(yaml_path, loss_fn, log_fn=default_log_fn, data_fn=de
                     
                     `compile_backend` (default: auto):
                         Backend to use for compiling the model.
-                        If "auto" the following backends will be tried in order:
-                        ["inductor", "aot_eager", "eager"]
+                        If "auto" the following backends will be tried in order: ["inductor", "aot_eager", "eager"]
+                        If "none" no compilation will occur.
                     
                     `load_checkpoint` (default: False): Whether to attempt loading model from checkpoint.
                     
@@ -612,6 +612,7 @@ def train_from_config_file(yaml_path, loss_fn, log_fn=default_log_fn, data_fn=de
             
             grad_clip_norm = general_config.get("grad_clip_norm", None)
             mixed_precision = general_config.get("mixed_precision", False) and device=="cuda"
+            if torch.cuda.is_available(): torch.set_float32_matmul_precision('high')
             
             loss_backoff_count = general_config.get("loss_backoff_count", 10)
             loss_backoff_type = general_config.get("loss_backoff_type", "consecutive")
